/* Copyright (C) 2000 by Massimiliano Ghilardi
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 */
#ifndef TWIN_SOCKET_H
#define TWIN_SOCKET_H

byte InitSocket(void);
void QuitSocket(void);

#endif /* TWIN_SOCKET_H */
